package MFInt32;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFInt32;
our $SField = new SFInt32;

1;
__END__
